/*
 *	dnsutl - utilities to make DNS easier to configure
 *	Copyright (C) 1996 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * MANIFEST: functions to manipulate ethers
 */

#include <ctype.h>
#include <ac/string.h>

#include <mem.h>
#include <srrf.h>
#include <srrf/private.h>


static int hex _((int));

static int
hex(c)
	int		c;
{
	static char	digit[] = "0123456789ABCDEFabcdef";
	static int	value[] = {
					0, 1, 2, 3, 4, 5, 6, 7, 8, 9,
					10, 11, 12, 13, 14, 15,
					10, 11, 12, 13, 14, 15,
				};
	char		*cp;

	cp = strchr(digit, c);
	if (!cp)
		return 0; /* should not happen */
	return value[cp - digit];
}


static string_ty *is_legal_ether_address _((string_ty *));

static string_ty *
is_legal_ether_address(s)
	string_ty	*s;
{
	int		nbytes;
	unsigned char	buffer[6 + 1]; /* must be more than 6 */
	char		*cp;

	cp = s->str_text;
	nbytes = 0;
	while (nbytes < SIZEOF(buffer))
	{
		if (!isxdigit(cp[0]))
			return 0;
		if (isxdigit(cp[1]))
		{
			buffer[nbytes++] = (hex(cp[0]) << 4) | hex(cp[1]);
			cp += 2;
		}
		else
			buffer[nbytes++] = hex(*cp++);
		if (*cp != ':')
			break;
		++cp;
	}
	if  (*cp != 0 || nbytes != 6)
		return 0;
	return
		str_format
		(
			"%x:%x:%x:%x:%x:%x",
			buffer[0],
			buffer[1],
			buffer[2],
			buffer[3],
			buffer[4],
			buffer[5]
		);
}


static void a_check _((srrf_t *));

static void
a_check(rp)
	srrf_t		*rp;
{
	string_ty	*tmp;

	tmp = is_legal_ether_address(rp->arg.string[0]);
	if (tmp)
	{
		/*
		 * replace the address given with one
		 * in a canonical form.
		 */
		str_free(rp->arg.string[0]);
		rp->arg.string[0] = tmp;
	}
	else
	{
		srrf_lex_error
		(
			"the string \"%s\" is not a legal Ethernet address",
			rp->arg.string[0]->str_text
		);
	}
}


static srrf_type_ty type[] =
{
	{ "a",		1, a_check,	},
};


/*
 * This symbol describes the class.
 * It should be the only symbol exported from this file.
 */
srrf_class_ty srrf_class_ether =
{
	"ether",
	type,
	SIZEOF(type)
};
