#!/bin/sh
#
#	dnsutl - utilities to make DNS easier to configure
#	Copyright (C) 1995, 1996 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# MANIFEST: Test the include file functionality
#
work=/tmp/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 1; fi

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

fail()
{
	set +x
	echo 'FAILED test of the include file functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
trap \"fail\" 1 2 3 15

mkdir $work
if test $? -ne 0 ; then exit 1; fi
cd $work
if test $? -ne 0 ; then fail; fi

#
# test the include file functionality
#
cat > test.in << 'fubar'
$origin just.a.test.
@ in soa just.a.test. hostmaster.just.a.test. 0 0 0 0 0
$include fred
fubar
if test $? -ne 0 ; then fail; fi
cat > fred << 'fubar'
fred in a 192.192.192.1
fubar
if test $? -ne 0 ; then fail; fi
cat > test.ok << 'fubar'
$origin just.a.test.
$config	maximum_name_length	15
$config	warning_name_length	0
$config	allow_upper_case	0
$line 2 "test.in"
@		in	soa	just.a.test. hostmaster.just.a.test. (
				0	; serial
				0	; refresh: 0 seconds
				0	; retry: 0 seconds
				0	; expire: 0 seconds
				0 )	; minimum: 0 seconds
$line 1 "fred"
fred		in	a	192.192.192.1
fubar
if test $? -ne 0 ; then fail; fi

$bin/dns-filter test.in test.out
if test $? -ne 0 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
